.. _markers-label:

Markers
=======

These routines facilitate the calculation of 3d movement kinematics for
marker-based video recordings.

Functions
---------

Optical Systems
^^^^^^^^^^^^^^^
* :func:`markers.analyze3Dmarkers` ... Kinematic analysis of video-basedrecordings of 3D markers
* :func:`markers.findTrajectory` ... Calculation of point trajectory, from initial position + sensor position/orientation

Details
-------
.. automodule:: markers
    :members:
